/*!
  @header ECEnumeratorIterator
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

 <pre>
  -------------------------------------------------------------------------
  Modification history

  19.07.06 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECEnumeratorIterator_H)
#define __ECEnumeratorIterator_H

#include <Foundation/Foundation.h>
#include <Encore/Encore.h>

/*!
 * @class ECEnumeratorIterator
 * @abstract Iterator which is based on an enumeration
 */
@interface ECEnumeratorIterator : ECObject <ECIterator> {
  @private
    NSEnumerator *enumerator;
    id nextObject;
    NSLock *lock;
}

/*!
 * @method initWithEnumerator
 * @param anEnumerator enumerator to iterate over
 * @result self
 */
- initWithEnumerator: (NSEnumerator *) anEnumerator;
- (void) dealloc;


/*!
 * @method hasNext
 * @result returns YES if there is at least a datum at the current iteration 
 *   step
 */
- (BOOL) hasNext;


/*!
 * @method next
 * @result returns the next object of the set to iterate or nil, if 
 * not existent
 */
- next;
@end
#endif
