/*!
  @header ECLoggingFormatter
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  18.01.06 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECLoggingFormatter_H)
#define __ECLoggingFormatter_H

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>
#include <Encore/ECLogging.h>


/*!
 * @protocol ECLoggingFormatter
 * @abstract Defines the interface of implementations which are used to
 *   format logging output
 */
@protocol ECLoggingFormatter <ECObject>

/*!
 * @method formatLoggingOutput
 * @abstract used to format a logging entry.
 * @param loggingLevel underlying logging level for the given message
 * @param formatString NSString format string
 * @param args arguments for the format string
 * @result formatted string
 */
- (NSString *) formatLoggingOutputForLevel: (ECLoggingLevel) loggingLevel
  format: (NSString *) formatString arguments: (va_list) args;
  
@end
#endif
