/*!
  @header ECLoggingXMLConfiguration
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  11.02.06 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECLoggingXMLConfiguration_H)
#define __ECLoggingXMLConfiguration_H

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>
#include <Encore/ECLoggingConfiguration.h>

@class ECLoggingContext;

/*!
 * @class ECLoggingXMLConfiguration
 * @abstract This class is used to configure ECLogging using ECXMLControl.
 */
@interface ECLoggingXMLConfiguration : ECObject 

/*!
 * @method addECLoggingContext
 * @param aContext
 * @abstract Used to register the given configuration
 * @result self
 */
- addECLoggingContext: (ECLoggingContext *) aContext;
@end


/******************************************************* ECLoggingContext */
/*!
 * @class ECLoggingContext
 * @abstract This class is used in conjunction with the XML-based configuration
 *   of ECLogging
 */
@interface ECLoggingContext : ECObject {
  @private 
    NSString *context;
    ECLoggingConfiguration *configuration;
    BOOL isRootContext;
}

- init;
- (void) dealloc;

/*!
 * @method context
 * @result returns the configured context string
 */
- (NSString *) context;


/*!
 * @method configuration
 * @result the logging configuration associated with the context
 */
- (ECLoggingConfiguration *) configuration;


/*!
 * @method isRootContext
 * @result YES if the receiver specifies the settings for the root context.
 *   In this case "-context" is meaningless.
 */
- (BOOL) isRootContext;


/*!
 * @method setContext
 * @abstract called by ECXMLControl in oder to set the context
 * @param aContext context to set
 * @result self
 */
- setContext: (NSString *) aContext;


/*!
 * @method setLoggingConfiguration
 * @abstract Called by ECXMLControl in order to assign a configuration to the
 *   the receiver
 * @param aConfiguration
 * @result self
 */
- setLoggingConfiguration: (ECLoggingConfiguration *) aConfiguration;


/*!
 * @method setRootContext
 * @param rootContext if this parameter equals YES then the receiver is
 *   meant to be the configuration for the root looger.
 * @result self
 */
- setRootContext: (NSString *) rootContext;
@end
#endif
