/*!
  @header ECMemory
  @abstract Module of Encore containing memory utility functions, macros etc.
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  23.02.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECMemory_H)
#define __ECMemory_H

/*!
 * @macro EC_AUTORELEASEPOOL_BEGIN
 * @abstract used to mark the beginning an autorelease pool
 * @discussion An autorelease pool instantiated with this macro
 *   will <b>always</b> be release independently wether an exception
 *   is thrown within its body or not since it is enclosed in a try..finalize
 *   block
 */
#define EC_AUTORELEASEPOOL_BEGIN \
  { NSAutoreleasePool *__pool;\
    __pool = [[NSAutoreleasePool alloc] init];
	

/*!
 * @macro FT_AUTORELEASEPOOL_END
 * @abstract marks the end of an autorelease pool
 * @see FT_AUTORELEASEPOOL_BEGIN
 */
#define EC_AUTORELEASEPOOL_END \
    [__pool release];\
  } 

/*!
 * @macro EC_AUTORELEASEPOOL_RELEASE
 * @abstract used to manually release the EC_AUTORELEASEPOOL.
 */
#define EC_AUTORELEASEPOOL_RELEASE \
  [__pool release]; __pool = nil;

#endif
