/*!
  @header ECStringUtils
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  05.02.06 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECStringUtils_H)
#define __ECStringUtils_H

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>

/*!
 * @category ECStringUtils
 * @abstract Enhances NSString wrt. to some utility methods
 */
@interface NSString (ECStringUtils)


/*!
 * @method splitStringUsingDelimiter
 * @abstract Splits the string into multiple parts. These parts are encountered
 *   by the given delimiter
 * @discussion if the string does not contain the delimiter then the whole
 *   original string will be returned as the first element of the array.<p/>
 *   The order of the elements (substrings) of the array corresponds to the
 *   order in which the substrings occur.<p/>
 *   Adds an empty string for each empty substring. A substring is empty, if 
 *   the content between delimiters or between a delimiter an the beginning or
 *   ending of the string does not contain any character.
 * @param delimiter 
 * @result array containing the substrings. Result may never equal nil
 */
- (NSArray *) splitStringUsingDelimiter: (NSString *) delimiter;
  
@end
#endif
