/*!
  @header ECTestResult
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  20.11.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECTestResult_h)
#define __ECTestResult_h

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>

/*!
 * @class ECTestResult
 * @abstract encapsulates the result of a testcase
 */
@interface ECTestResult : ECObject {
  @private 
    BOOL testcaseRanSuccessfully;
    NSException *exception;
}

/*!
 * @method initWithSuccess
 * @abstract initializes this instance indicating that the
 *   the operation has been successfully launched.
 * @result self
 */
- initWithSuccess;


/*!
 * @method initWithException
 * @abstract Using this initializer marks the result as
 *   a failure and stores the underlying exception
 * @param anException Exception causing the failure
 * @result self
 */
- initWithException: (NSException *) anException;
- (void) dealloc;


/*!
 * @method exception
 * @result returns the exception causing the failure of the testcase.
 *   Returns nil if testcase ran successfully
 */
- (NSException *) exception;


/*!
 * @method successful
 * @result YES if operation (testcase) has been successfully run
 */
- (BOOL) successful;
@end
#endif

