/*!
  @header ECTestSuite
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  20.11.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECTestSuite_h)
#define __ECTestSuite_h

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>
#include <Encore/ECTestcase.h>

/*!
 * @class ECTestSuite
 * @abstract A simple class to perform simple tests
 */
@interface ECTestSuite : ECObject {
  @private 
    NSMutableArray *listOfTestcases;
    NSMutableArray *listOfMethodsOfTestcases;
    
    BOOL proceedOnFailure;
}

- init;
- (void) dealloc;


/*!
 * @method addTest
 * @abstract Adds a testcase to the set 
 * @param testCaseToAdd testcase to add
 * @param withSelector underlying method to call
 * @return self
 */
- addTestcase: (ECTestcase *) testcaseToAdd 
  withSelector: (SEL) methodToCall;


/*!
 * @method proceedOnFailure
 * @abstract By default the underlying flag equals NO so that assertion failures
 *   will throw an {@link ECAssertionException}
 * @param doIt if YES then the {@link ECAssertionException} will NOT be thrown
 *   in case of an assertion failure. The result (failure) will be marked in and
 *   returned by the result array and the test run will proceed.
 * @result self
 */
- proceedOnFailure: (BOOL) doIt;


/*!
 * @method runTestcases
 * @result an error of results of type {@link ECTestResult}
 * @abstract Starts the tests
 * @discussion For each testcase being added this method
 *   initiates the following methods in their given order:
 *   <ul>
 *     <li>setup</li>
 *     <li>cleanup</li>
 *   </ul>
 */
- (NSArray *) runTestcases;

@end
#endif

