/*!
  @header ECXMLControlDefaultAllocator
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA


  <pre>
  -------------------------------------------------------------------------
  Modification history

  27.11.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECXMLControlDefaultAllocatorRule_H)
#define __ECXMLControlDefaultAllocatorRule_H

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>
#include <Encore/ECXMLControlRule.h>
#include <Encore/ECXMLControlContext.h>


/*!
 * @macro __CLASS_ATTRIBUTE
 * name of attribute which specifies the class name
 */
#define __CLASS_ATTRIBUTE @"class"


/*!
 * @class ECXMLControlDefaultAllocator
 * @abstract This rule allocates the appropriate instance for a
 *   given XML element.
 * @discussion
 *   It first looks for an xml attribute "class". if found then it takes the
 *   class specified by this attribute in order to allocate the instance.
 *   Otherwise it uses the name of the xml element type in order to
 *   find get the related class object ("class by name") and then to
 *   allocate the instance.
 */
@interface ECXMLControlDefaultAllocatorRule : ECObject <ECXMLControlRule>

- (BOOL) mayActOn: (ECXMLControlContext *) aContext;

- (BOOL) actOn: (ECXMLControlContext *) aContext;
@end
#endif
