/*!
  @header ECXMLControlDelegateMessageRule
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  05.08.06 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECXMLControlDelegateMessageRule_H)
#define __ECXMLControlDelegateMessageRule_H

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>
#include <Encore/ECXMLControlRule.h>


/*!
 * @class ECXMLControlDelegateMessageRule
 * @abstract If fired this rule delegates the event to a specified 
 *   method of a specified object
 */
@interface ECXMLControlDelegateMessageRule : ECObject <ECXMLControlRule> {
  @private
    id delegationTarget;
    SEL selectorToCall;
    NSString *xmlElementTypename;
}


/*!
 * @method initWithDelegationTarget
 * @abstract Used to specify the method to call in case this rule is fired.
 * @param aDelegationtarget related object to consult
 * @param aSelectorToCall selector to call. An instance of ECXMLContronContext
 *   will be passed as parameter to this selector in case this rule fires
 * @param aTypename name of xml element type to react on
 * @result self
 */
- initWithDelegationTarget: (id) aDelegationtarget
  selectorToCall: (SEL) aSelectorToCall
  forXMLElementTypename: (NSString *) aTypename;  
- (void) dealloc;


/*!
 * @method respondsToContext
 * @param aContext current context to evaluate
 * @result YES if the receiver should be valuated according to the given 
 *   context
 */
- (BOOL) mayActOn: (ECXMLControlContext *) aContext;


/*!
 * @method actOn
 * @param aContext current context to evaluate
 * @result YES if no more rules should be evaluated
 */
- (BOOL) actOn: (ECXMLControlContext *) aContext;

@end
#endif
