/*!
  @header ECXMLControlRuleSelector
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  27.11.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__ECXMLControlRuleSelector_H)
#define __ECXMLControlRuleSelector_H

#include <Foundation/Foundation.h>
#include <Encore/ECObject.h>
#include <Encore/ECKeyToListMap.h>
#include <Encore/ECXMLControlRule.h>
#include <Encore/ECXMLControlDefaultRule.h>

/*!
 * @class ECXMLControlRuleSelector
 * @abstract Used to select a rule based on an XML event
 */
@interface ECXMLControlRuleSelector : ECObject {
  @private
    NSMutableArray *rules;
    ECKeyToListMap *eventIdToRuleMap;
}

- init;
- (void) dealloc;

/*!
 * @method addRule
 * @abstract adds a rule for a certain event
 * @param newRule corresponding rule
 * @param anEvent one of the fields "event_XXX" (see {@link ECXMLControlEvent}
 * @result self
 */
- addRule: (id <ECXMLControlRule>) newRule forEvent: (id) anEvent;


- performRulesForContext: (ECXMLControlContext *) aContext;
@end
#endif
